==> haskell-binary-conduit-1.3-43-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-conduit
version: 1.3
id: binary-conduit-1.3-FOJ94JF1Ddf7QjAGY0WMA0
key: binary-conduit-1.3-FOJ94JF1Ddf7QjAGY0WMA0
license: MIT
copyright: 2013 Alexander Vershilov
maintainer: alexander.vershilov@gmail.com
author: Alexander Vershilov
stability: Experimental
homepage: http://github.com/qnikst/binary-conduit/
synopsis: data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.
category: Conduit
abi: 0898810b399d377770dd2d776f894fa3
exposed: True
exposed-modules:
    Data.Conduit.Serialization.Binary
import-dirs: /usr/lib/ghc-8.4.3/site-local/binary-conduit-1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/binary-conduit-1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/binary-conduit-1.3
hs-libraries: HSbinary-conduit-1.3-FOJ94JF1Ddf7QjAGY0WMA0
depends:
    base-4.11.1.0 conduit-1.3.0.3-ItTdkX5aIYADBgSo6qkTtM
    bytestring-0.10.8.2 binary-0.8.5.1
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             conduit-1.3.0.3-ItTdkX5aIYADBgSo6qkTtM=c18f362c48e9cd5e7e333f51329c375a
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
haddock-interfaces: /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock
haddock-html: /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-conduit-1.3-45-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-conduit
version: 1.3
id: binary-conduit-1.3-AkhCnMK9fouAEX9VIjKbDX
key: binary-conduit-1.3-AkhCnMK9fouAEX9VIjKbDX
license: MIT
copyright: 2013 Alexander Vershilov
maintainer: alexander.vershilov@gmail.com
author: Alexander Vershilov
stability: Experimental
homepage: http://github.com/qnikst/binary-conduit/
synopsis: data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.
category: Conduit
abi: 237c1d1839e9f8eb32f38a6985d53674
exposed: True
exposed-modules:
    Data.Conduit.Serialization.Binary
import-dirs: /usr/lib/ghc-8.4.3/site-local/binary-conduit-1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/binary-conduit-1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/binary-conduit-1.3
hs-libraries: HSbinary-conduit-1.3-AkhCnMK9fouAEX9VIjKbDX
depends:
    base-4.11.1.0 conduit-1.3.0.3-3QvHPY7A7wG9dCAq8NocHt
    bytestring-0.10.8.2 binary-0.8.5.1
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             conduit-1.3.0.3-3QvHPY7A7wG9dCAq8NocHt=b1dfd4192082da4558423bbab6ade87a
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
haddock-interfaces: /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock
haddock-html: /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
